@@ -35,10 +35,7 @@ log = logger.create()
 
 
 def b64encode_json(json_data):
-    if sys.version_info < (3, 0):
-        return b64encode(json.dumps(json_data))
-    else:
-        return b64encode(json.dumps(json_data).encode())
+    return b64encode(json.dumps(json_data).encode())
 
 
 # Python3 has a timestamp() method we could be calling, however it's not avaiable in python2.
@@ -85,8 +82,8 @@ class SyncToken:
             "books_last_created": {"type": "string"},
             "archive_last_modified": {"type": "string"},
             "reading_state_last_modified": {"type": "string"},
-            "tags_last_modified": {"type": "string"},
-            "books_last_id": {"type": "integer", "optional": True}
+            "tags_last_modified": {"type": "string"}
+            # "books_last_id": {"type": "integer", "optional": True}
         },
     }
 
@@ -97,8 +94,8 @@ class SyncToken:
         books_last_modified=datetime.min,
         archive_last_modified=datetime.min,
         reading_state_last_modified=datetime.min,
-        tags_last_modified=datetime.min,
-        books_last_id=-1
+        tags_last_modified=datetime.min
+        # books_last_id=-1
     ):  # nosec
         self.raw_kobo_store_token = raw_kobo_store_token
         self.books_last_created = books_last_created
@@ -106,7 +103,7 @@ class SyncToken:
         self.archive_last_modified = archive_last_modified
         self.reading_state_last_modified = reading_state_last_modified
         self.tags_last_modified = tags_last_modified
-        self.books_last_id = books_last_id
+        # self.books_last_id = books_last_id
 
     @staticmethod
     def from_headers(headers):
@@ -141,12 +138,12 @@ class SyncToken:
             archive_last_modified = get_datetime_from_json(data_json, "archive_last_modified")
             reading_state_last_modified = get_datetime_from_json(data_json, "reading_state_last_modified")
             tags_last_modified = get_datetime_from_json(data_json, "tags_last_modified")
-            books_last_id = data_json["books_last_id"]
+            # books_last_id = data_json["books_last_id"]
         except TypeError:
             log.error("SyncToken timestamps don't parse to a datetime.")
             return SyncToken(raw_kobo_store_token=raw_kobo_store_token)
-        except KeyError:
-            books_last_id = -1
+        #except KeyError:
+        #    books_last_id = -1
 
         return SyncToken(
             raw_kobo_store_token=raw_kobo_store_token,
@@ -155,7 +152,7 @@ class SyncToken:
             archive_last_modified=archive_last_modified,
             reading_state_last_modified=reading_state_last_modified,
             tags_last_modified=tags_last_modified,
-            books_last_id=books_last_id
+            #books_last_id=books_last_id
         )
 
     def set_kobo_store_header(self, store_headers):
@@ -179,16 +176,16 @@ class SyncToken:
                 "archive_last_modified": to_epoch_timestamp(self.archive_last_modified),
                 "reading_state_last_modified": to_epoch_timestamp(self.reading_state_last_modified),
                 "tags_last_modified": to_epoch_timestamp(self.tags_last_modified),
-                "books_last_id":self.books_last_id
+                #"books_last_id":self.books_last_id
             },
         }
         return b64encode_json(token)
 
     def __str__(self):
-        return "{},{},{},{},{},{},{}".format(self.raw_kobo_store_token,
+        return "{},{},{},{},{},{}".format(self.raw_kobo_store_token,
                                        self.books_last_created,
                                        self.books_last_modified,
                                        self.archive_last_modified,
                                        self.reading_state_last_modified,
-                                       self.tags_last_modified,
-                                       self.books_last_id)
+                                       self.tags_last_modified)
+                                       #self.books_last_id)
