@@ -85,7 +85,7 @@ $(function() {
             method:"post",
             contentType: "application/json; charset=utf-8",
             dataType: "json",
-            url: window.location.pathname + "/../../ajax/mergebooks",
+            url: window.location.pathname + "/../ajax/mergebooks",
             data: JSON.stringify({"Merge_books":selections}),
             success: function success() {
                 $("#books-table").bootstrapTable("refresh");
@@ -104,7 +104,7 @@ $(function() {
             method:"post",
             contentType: "application/json; charset=utf-8",
             dataType: "json",
-            url: window.location.pathname + "/../../ajax/simulatemerge",
+            url: window.location.pathname + "/../ajax/simulatemerge",
             data: JSON.stringify({"Merge_books":selections}),
             success: function success(booTitles) {
                 $.each(booTitles.from, function(i, item) {
@@ -121,7 +121,7 @@ $(function() {
             method:"post",
             contentType: "application/json; charset=utf-8",
             dataType: "json",
-            url: window.location.pathname + "/../../ajax/xchange",
+            url: window.location.pathname + "/../ajax/xchange",
             data: JSON.stringify({"xchange":selections}),
             success: function success() {
                 $("#books-table").bootstrapTable("refresh");
@@ -149,6 +149,10 @@ $(function() {
                     }
                 }
             };
+            if ($(this).attr("data-editable-type") == "wysihtml5") {
+                //if (this.id == "comments") {
+                element.editable.display = shorten_html;
+            }
             var validateText = $(this).attr("data-edit-validate");
             if (validateText) {
                 element.editable.validate = function (value) {
@@ -158,13 +162,15 @@ $(function() {
         }
         column.push(element);
     });
+    // $.fn.editable.defaults.display = comment_display;
 
     $("#books-table").bootstrapTable({
         sidePagination: "server",
+        pageList: "[10, 25, 50, 100]",
         queryParams: queryParams,
         pagination: true,
         paginationLoop: false,
-        paginationDetailHAlign: " hidden",
+        paginationDetailHAlign: "right",
         paginationHAlign: "left",
         idField: "id",
         uniqueId: "id",
@@ -187,7 +193,7 @@ $(function() {
                 $.ajax({
                     method:"get",
                     dataType: "json",
-                    url: window.location.pathname + "/../../ajax/sort_value/" + field + "/" + row.id,
+                    url: window.location.pathname + "/../ajax/sort_value/" + field + "/" + row.id,
                     success: function success(data) {
                         var key = Object.keys(data)[0];
                         $("#books-table").bootstrapTable("updateCellByUniqueId", {
@@ -215,7 +221,7 @@ $(function() {
                 method:"post",
                 contentType: "application/json; charset=utf-8",
                 dataType: "json",
-                url: window.location.pathname + "/../../ajax/table_settings",
+                url: window.location.pathname + "/../ajax/table_settings",
                 data: "{" + st + "}",
             });
         },
@@ -638,6 +644,13 @@ function singlecheckboxFormatter(value, row){
         return '<input type="checkbox" class="chk" data-pk="' + row.id + '" data-name="' + this.field + '" onchange="checkboxChange(this, ' + row.id + ', \'' + this.name + '\', 0)">';
 }
 
+function ratingFormatter(value, row) {
+    if (value == 0) {
+        return "";
+    }
+    return (value/2);
+}
+
 
 /* Do some hiding disabling after user list is loaded */
 function loadSuccess() {
@@ -769,7 +782,7 @@ function handleListServerResponse (data) {
     $("#flash_danger").remove();
     if (!jQuery.isEmptyObject(data)) {
         data.forEach(function(item) {
-            $(".navbar").after('<div class="row-fluid text-center" style="margin-top: -20px;">' +
+            $(".navbar").after('<div class="row-fluid text-center">' +
                 '<div id="flash_' + item.type + '" class="alert alert-' + item.type + '">' + item.message + '</div>' +
                 '</div>');
         });
@@ -870,3 +883,10 @@ function user_handle (userId) {
     });
     $("#user-table").bootstrapTable("refresh");
 }
+
+function shorten_html(value, response) {
+    if(value) {
+        $(this).html("[...]");
+        // value.split('\n').slice(0, 2).join("") +
+    }
+}
